==> websvn-2.3.3-8-any.pkg.tar.xz: srv/http/websvn/languages/ukrainian.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// ukrainian.php
//
// Ukrainian language strings (UTF-8 encoding) 
// by Vitaliy Tsybulyak <fauve@ukr.net>

$lang["LANGUAGETAG"] = "uk"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Ukrainian";
$lang["LANGUAGENAMENATIVE"] = "Українська";
$lang["LANGUAGENAMEHTML"] = "&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072;";

$lang["LOG"] = "Журнал";
$lang["DIFF"] = "Відмінності";

$lang["NOREP"] = "Репозитарію не вказано";  
$lang["NOPATH"] = "Шлях не знайдено";   
$lang["NOACCESS"] = "У вас недостатньо дозволів на читання цього каталогу"; 
$lang["RESTRICTED"] = "Обмежений доступ";
$lang["SUPPLYREP"] = "Задайте будь ласка шлях до репозитарію в include/config.php за допомогою <code>\$config->parentPath</code> або <code>\$config->addRepository</code>. Додатковий опис можна знайти в довіднику зі встановлення.";

$lang["DIFFREVS"] = "Відмінності між редагуваннями";
$lang["AND"] = "і";     
$lang["REV"] = "Версія";    
$lang["LINE"] = "Рядок";    
$lang["LINENO"] = "№ рядка"; 
$lang["SHOWENTIREFILE"] = "Показати увесь файл";                
$lang["SHOWCOMPACT"] = "Показати тільки ділянки з відмінностями"; 
$lang["IGNOREWHITESPACE"] = "Ігнорувати пробіли";
$lang["REGARDWHITESPACE"] = "Зважати на пробіли";

$lang["LISTING"] = "Вивід вмісту каталогу";
$lang["FILEDETAIL"] = "Докладніше"; 
$lang["VIEWAS"] = "Показати як";
$lang["DIFFPREV"] = "Порівняти з попередньою"; 
$lang["BLAME"] = "Авторство"; 
$lang["BLAMEFOR"] = "Інформація про авторство версії";

$lang["REVINFO"] = "Інформація про версію";
$lang["GOYOUNGEST"] = "Перейти до найостаннішої версії";
$lang["LASTMOD"] = "Остання зміна";
$lang["LOGMSG"] = "Запис у журналі";
$lang["CHANGES"] = "Зміни";
$lang["SHOWCHANGED"] = "Показати змінені файли";
$lang["HIDECHANGED"] = "Сховати змінені файли";
$lang["NEWFILES"] = "Нові файли";
$lang["CHANGEDFILES"] = "Змінені файли";
$lang["DELETEDFILES"] = "Вилучені файли";
$lang["VIEWLOG"] = "Журнал";
$lang["PATH"] = "Шлях";
$lang["AUTHOR"] = "Автор";
$lang["AGE"] = "Вік";
$lang["CURDIR"] = "Поточний каталог";
$lang["TARBALL"] = "Tar";
$lang["DOWNLOAD"] = "Завантажити";

$lang["PREV"] = "Поперед.";
$lang["NEXT"] = "Наступн.";
$lang["SHOWALL"] = "Показати все";

$lang["BADCMD"] = "Помилка при виконанні команди";
$lang["UNKNOWNREVISION"] = "Цієї версії не знайдено";

$lang["POWERED"] = "Працює на <a href=\"http://www.websvn.info/\">WebSVN</a>";
$lang["PROJECTS"] = "Репозитарії&nbsp;Subversion";
$lang["SERVER"] = "Сервер&nbsp;Subversion";

$lang["FILTER"] = "Параметри фільтрації";
$lang["STARTLOG"] = "Від версії";
$lang["ENDLOG"] = "По версію";
$lang["MAXLOG"] = "Макс. версій";
$lang["SEARCHLOG"] = "Шукати в історії";
$lang["CLEARLOG"] = "Очистити поточний фільтр";
$lang["MORERESULTS"] = "Знайти ще збіги...";
$lang["NORESULTS"] = "Записів, які би збігалися з вашим запитом, не знайдено";
$lang["NOMORERESULTS"] = "Більше немає записів, які би збігалися з вашим запитом";
$lang["NOPREVREV"] = "Попередньої версії не існує";

$lang["RSSFEEDTITLE"] = "RSS WebSVN";
$lang["FILESMODIFIED"] = "файл(ів) змінено";
$lang["RSSFEED"] = "RSS";

$lang["DAYLETTER"] = "д";
$lang["HOURLETTER"] = "г";
$lang["MINUTELETTER"] = "х";
$lang["SECONDLETTER"] = "с";

$lang["GO"] = "Перейти";

$lang["PATHCOMPARISON"] = "Порівняння шляхів";
$lang["COMPAREPATHS"] = "Порівняти шляхи";
$lang["COMPAREREVS"] = "Порівняти версії";
$lang["PROPCHANGES"] = "Зміна властивостей:";
$lang["CONVFROM"] = "Таке порівнювання показує зміни, потрібні для перетворення шляху ";
$lang["TO"] = "у";
$lang["REVCOMP"] = "Обернене порівняння";
$lang["COMPPATH"] = "Порівняти шлях:";
$lang["WITHPATH"] = "Зі шляхом:";
$lang["FILEDELETED"] = "Файл вилучено";
$lang["FILEADDED"] = "Новий файл";

==> websvn-2.5-1-any.pkg.tar.xz: srv/http/websvn/languages/ukrainian.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// ukrainian.php
//
// Ukrainian language strings (UTF-8 encoding) 
// by Vitaliy Tsybulyak <fauve@ukr.net>

$lang["LANGUAGETAG"] = "uk"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Ukrainian";
$lang["LANGUAGENAMENATIVE"] = "Українська";
$lang["LANGUAGENAMEHTML"] = "&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072;";

$lang["LOG"] = "Журнал";
$lang["DIFF"] = "Відмінності";

$lang["NOREP"] = "Репозитарію не вказано";  
$lang["NOPATH"] = "Шлях не знайдено";   
$lang["NOACCESS"] = "У вас недостатньо дозволів на читання цього каталогу"; 
$lang["RESTRICTED"] = "Обмежений доступ";
$lang["SUPPLYREP"] = "Задайте будь ласка шлях до репозитарію в include/config.php за допомогою <code>\$config->parentPath</code> або <code>\$config->addRepository</code>. Додатковий опис можна знайти в довіднику зі встановлення.";

$lang["DIFFREVS"] = "Відмінності між редагуваннями";
$lang["AND"] = "і";     
$lang["REV"] = "Версія";    
$lang["LINE"] = "Рядок";    
$lang["LINENO"] = "№ рядка"; 
$lang["SHOWENTIREFILE"] = "Показати увесь файл";                
$lang["SHOWCOMPACT"] = "Показати тільки ділянки з відмінностями"; 
$lang["IGNOREWHITESPACE"] = "Ігнорувати пробіли";
$lang["REGARDWHITESPACE"] = "Зважати на пробіли";

$lang["LISTING"] = "Вивід вмісту каталогу";
$lang["FILEDETAIL"] = "Докладніше"; 
$lang["VIEWAS"] = "Показати як";
$lang["DIFFPREV"] = "Порівняти з попередньою"; 
$lang["BLAME"] = "Авторство"; 
$lang["BLAMEFOR"] = "Інформація про авторство версії";

$lang["REVINFO"] = "Інформація про версію";
$lang["GOYOUNGEST"] = "Перейти до найостаннішої версії";
$lang["LASTMOD"] = "Остання зміна";
$lang["LOGMSG"] = "Запис у журналі";
$lang["CHANGES"] = "Зміни";
$lang["SHOWCHANGED"] = "Показати змінені файли";
$lang["HIDECHANGED"] = "Сховати змінені файли";
$lang["NEWFILES"] = "Нові файли";
$lang["CHANGEDFILES"] = "Змінені файли";
$lang["DELETEDFILES"] = "Вилучені файли";
$lang["VIEWLOG"] = "Журнал";
$lang["PATH"] = "Шлях";
$lang["AUTHOR"] = "Автор";
$lang["AGE"] = "Вік";
$lang["CURDIR"] = "Поточний каталог";
$lang["TARBALL"] = "Tar";
$lang["DOWNLOAD"] = "Завантажити";

$lang["PREV"] = "Поперед.";
$lang["NEXT"] = "Наступн.";
$lang["SHOWALL"] = "Показати все";

$lang["BADCMD"] = "Помилка при виконанні команди";
$lang["UNKNOWNREVISION"] = "Цієї версії не знайдено";

$lang["POWERED"] = "Працює на <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Репозитарії&nbsp;Subversion";
$lang["SERVER"] = "Сервер&nbsp;Subversion";

$lang["FILTER"] = "Параметри фільтрації";
$lang["STARTLOG"] = "Від версії";
$lang["ENDLOG"] = "По версію";
$lang["MAXLOG"] = "Макс. версій";
$lang["SEARCHLOG"] = "Шукати в історії";
$lang["CLEARLOG"] = "Очистити поточний фільтр";
$lang["MORERESULTS"] = "Знайти ще збіги...";
$lang["NORESULTS"] = "Записів, які би збігалися з вашим запитом, не знайдено";
$lang["NOMORERESULTS"] = "Більше немає записів, які би збігалися з вашим запитом";
$lang["NOPREVREV"] = "Попередньої версії не існує";

$lang["RSSFEEDTITLE"] = "RSS WebSVN";
$lang["FILESMODIFIED"] = "файл(ів) змінено";
$lang["RSSFEED"] = "RSS";

$lang["DAYLETTER"] = "д";
$lang["HOURLETTER"] = "г";
$lang["MINUTELETTER"] = "х";
$lang["SECONDLETTER"] = "с";

$lang["GO"] = "Перейти";

$lang["PATHCOMPARISON"] = "Порівняння шляхів";
$lang["COMPAREPATHS"] = "Порівняти шляхи";
$lang["COMPAREREVS"] = "Порівняти версії";
$lang["PROPCHANGES"] = "Зміна властивостей:";
$lang["CONVFROM"] = "Таке порівнювання показує зміни, потрібні для перетворення шляху ";
$lang["TO"] = "у";
$lang["REVCOMP"] = "Обернене порівняння";
$lang["COMPPATH"] = "Порівняти шлях:";
$lang["WITHPATH"] = "Зі шляхом:";
$lang["FILEDELETED"] = "Файл вилучено";
$lang["FILEADDED"] = "Новий файл";
